@@ -16,7 +16,7 @@ require AutoLoader;
 
 @EXPORT_OK = qw(mgetpwnam setpwinfo rmpwnam init_db modpwinfo);
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 my %_Create_Flags = (
 		     'freebsd' => 0x200,
@@ -27,8 +27,8 @@ my %_Create_Flags = (
 my %_DB_Global = ();
 $_DB_Global{'Database'} = $ENV{'PWDDatabase'};
 
-if (defined($_Create_Flags{$})) {
-    $_DB_Global{'CFlags'} = $_Create_Flags{$};
+if (defined($_Create_Flags{$^O})) {
+    $_DB_Global{'CFlags'} = $_Create_Flags{$^O};
 } else {
     $_DB_Global{'CFlags'} = 0x100;
 }
@@ -38,7 +38,7 @@ if (defined($_Create_Flags{$})) {
 sub new {
     my $class = shift;
     my $self = {};
-    
+
     bless $self, $class;
     if ((scalar(@_) >= 3) || (scalar(@_) < 1)) {
         croak "$class: $class->new('/path/to/database_file' [, 'create'])";
@@ -71,7 +71,7 @@ sub init_db ($;$) {
 sub _create_db ($) {
     my ($db) = @_;
     my (%dbm);
-    
+
     tie (%dbm, 'DB_File', $db, $_DB_Global{'CFlags'}|2, 0640, $DB_HASH) or do {
 	croak "Couldn't create $db : $!";
     };
@@ -237,7 +237,7 @@ sub rmpwnam ($) {
     }
     return 0;
 }
-  
+
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
